@@ -8,6 +8,8 @@ from flagai.model.predictor.utils import viterbi_decode, decode_labels, bert_bea
     t5_random_sample, gpt_random_sample, \
     t5_beamsearch, gpt_beamsearch, bert_random_sample, glm_beamsearch, glm_random_sample
 from typing import List, Union, Dict, Tuple, Any
+from flagai.model.predictor.gpt import gpt_random_sample_use_cache
+
 
 class Predictor:
 
@@ -277,7 +279,7 @@ class Predictor:
                                     device)
 
         elif "gpt" in self.class_name.lower() or "opt" in self.class_name.lower():
-            return gpt_random_sample(self.model, self.tokenizer, text,
+            return gpt_random_sample_use_cache(self.model, self.tokenizer, text,
                                      input_max_length, out_max_length, top_k,
                                      top_p, repetition_penalty, temperature,
                                      device)
