@@ -198,22 +198,30 @@ class Trainer():
         self.not_call_launch = True
         self.deepspeed_config = deepspeed_config
         self.model_parallel_size = model_parallel_size
-        if 'deepspeed' in env_type or env_type == 'pytorchDDP':
+        self.num_nodes = num_nodes
+        self.num_gpus = num_gpus
+        self.master_ip = master_ip
+        self.master_port = master_port
+        self.hostfile = hostfile
+        self.training_script = training_script
+
+        if 'deepspeed' in self.env_type or self.env_type == 'pytorchDDP':
+            training_paras = self.get_dist_args()
             # Implement for AutoLaunch
             # >>> python train.py # will call get_dist_args()
             # `--not_call_launch` is default 'False'
             # So, if `env_type` is `pytorch`, the `Trainer` will not call lanch_dist()
             # Otherwise, the lanch_dist() is called to launch 'train.py' with `--not_call_launch`
-            self.get_dist_args()
             if not self.not_call_launch:
                 launch_dist(launcher='distributed_deepspeed' if 'deepspeed'
                             in env_type else 'distributed_torch',
-                            num_nodes=num_nodes,
-                            gpus_per_node=num_gpus,
-                            master_addr=master_ip,
-                            master_port=master_port,
-                            hostfile=hostfile,
-                            training_script=training_script)
+                            num_nodes=self.num_nodes,
+                            gpus_per_node=self.num_gpus,
+                            master_addr=self.master_ip,
+                            master_port=self.master_port,
+                            hostfile=self.hostfile,
+                            training_script=self.training_script,
+                            training_paras=training_paras)
                 os._exit(1)
             self.initialize_distributed()
 
@@ -239,6 +247,7 @@ class Trainer():
         self.master_addr = os.environ.get('MASTER_ADDR', '127.0.0.1')
         self.master_port = os.environ.get('MASTER_PORT', '17500')
         log_dist("not_call_launch: {}".format(ds_args.not_call_launch))
+        return []
 
     def set_seed(self, seed=1234):
         """Set random seed for reproducability."""
@@ -310,8 +319,12 @@ class Trainer():
         else:
             if self.env_type == 'deepspeed+mpu':
                 rank = mpu.get_model_parallel_src_rank()
+                print("*"*80)
+                print("local rank",self.rank, "model rank", rank)
+                print("*"*80)
                 sampler = torch.utils.data.distributed.DistributedSampler(
                     dataset,
+                    # num_replicas=num_replicas,
                     rank=rank,
                     shuffle=shuffle)
             else:
@@ -335,7 +348,8 @@ class Trainer():
               train_dataset=None,
               valid_dataset=None,
               metric_methods=[],
-              collate_fn=None):
+              collate_fn=None,
+              find_unused_parameters=True):
         """Training Loops"""
         """
        Trainer is a simple but unifed training and eval loop for PyTorch/Deepspeed/Megatron-LM.
@@ -403,7 +417,7 @@ class Trainer():
             model.to(torch.device('cuda', self.local_rank))
             model = DDP(model,
                         device_ids=[self.local_rank],
-                        find_unused_parameters=True)
+                        find_unused_parameters=find_unused_parameters)
 
         elif self.env_type == 'pytorch':
             model.to(self.pytorch_device)
@@ -471,6 +485,9 @@ class Trainer():
         for epoch in range(self.epochs):
             # log_dist('working on epoch {} ...'.format(epoch), [0])
             # Set the data loader epoch to shuffle the index iterator.
+            # if self.env_type == 'deepspeed+mpu':
+            #     if mpu.get_model_parallel_rank() == 0:
+            #         train_dataloader.sampler.set_epoch(epoch + self.world_size)
             if self.env_type != 'pytorch':
                 train_dataloader.sampler.set_epoch(epoch + self.world_size)
 
@@ -502,7 +519,8 @@ class Trainer():
                                                            lr_scheduler,
                                                            single_step=True)
                     dist.barrier()
-                total_lm_loss += lm_loss.data.detach().float()
+                if lm_loss is not None:
+                    total_lm_loss += lm_loss.data.detach().float()
 
                 # Logging.
                 if (self.iteration + 1) % self.log_interval == 0:
@@ -919,23 +937,27 @@ class Trainer():
                     labels = data_iterator['labels']
                 else:
                     labels = data_iterator['target_ids']
-
-                all_logits.append(logits)
-                all_labels.append(labels)
+                if len(self.metric_methods) != 0:
+                    all_logits.append(logits)
+                    all_labels.append(labels)
                 all_losses.append(lm_loss.view(1))
 
-            all_logits = torch.cat(all_logits, dim=0)
-            all_labels = torch.cat(all_labels, dim=0)
+            if len(self.metric_methods) != 0:
+                all_logits = torch.cat(all_logits, dim=0)
+                all_labels = torch.cat(all_labels, dim=0)
+
             all_losses = torch.cat(all_losses, dim=0)
 
             if self.env_type == 'pytorchDDP' or self.env_type == 'deepspeed':
-                all_logits = self._gather_all(all_logits)
-                all_labels = self._gather_all(all_labels)
+                if len(self.metric_methods) != 0:
+                    all_logits = self._gather_all(all_logits)
+                    all_labels = self._gather_all(all_labels)
                 all_losses = self._gather_all(all_losses)
 
             elif self.env_type == 'deepspeed+mpu':
-                all_logits = self._gather_all_mpu(all_logits)
-                all_labels = self._gather_all_mpu(all_labels)
+                if len(self.metric_methods) != 0:
+                    all_logits = self._gather_all_mpu(all_logits)
+                    all_labels = self._gather_all_mpu(all_labels)
                 all_losses = self._gather_all_mpu(all_losses)
 
             if all_losses.device != torch.device('cpu'):
@@ -1017,3 +1039,4 @@ class Trainer():
         log_dist(string, [0])
         log_dist('-' * length, [0])
         return eval_dict
+
